

/* write button: CmapA1 */
#define CmapA1_offo_width 34
#define CmapA1_offo_height 14
static char CmapA1_offo_label[] = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0x00, 0x00, 0x00, 0x00,
  0x44, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x22, 0xd2, 0xe4, 0x61,
  0x00, 0x22, 0x32, 0x44, 0x90, 0x00, 0x54, 0x11, 0x44, 0x08, 0x01, 0x54,
  0x11, 0x44, 0xf8, 0x01, 0x54, 0x11, 0x44, 0x08, 0x00, 0x88, 0x10, 0x44,
  0x10, 0x01, 0x88, 0x10, 0x84, 0xe1, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
static char CmapA1_offo_mask[] = {
  0x00, 0x00, 0x0e, 0x00, 0x00, 0x00, 0x00, 0xee, 0x00, 0x00, 0x00, 0x00,
  0xee, 0x00, 0x00, 0x77, 0xff, 0xff, 0xf3, 0x00, 0x77, 0xff, 0xff, 0xfb,
  0x01, 0xff, 0xff, 0xff, 0xff, 0x03, 0xff, 0x7f, 0xee, 0xfc, 0x03, 0xfe,
  0x3b, 0xee, 0xfc, 0x03, 0xfe, 0x3b, 0xee, 0xfc, 0x03, 0xfe, 0x3b, 0xee,
  0xff, 0x03, 0xdc, 0x39, 0xee, 0xfb, 0x03, 0xdc, 0x39, 0xce, 0xf3, 0x01,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
static int CmapA1_offo_breaks[] = { 11, 17, 20, 26, 34 };
static ButtonLabel CmapA1_offo = {
  (unsigned char *)CmapA1_offo_label, (unsigned char *)CmapA1_offo_mask,
  CmapA1_offo_width, CmapA1_offo_height,
  0.5, 0.5, 0, 0,			/* placement */
  5, 5, 0, CmapA1_offo_breaks };
#define CmapA1_offi_width 35
#define CmapA1_offi_height 14
static char CmapA1_offi_label[] = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0c, 0x00, 0x00, 0x00, 0x00,
  0xcc, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x00, 0x00, 0x23, 0xf6, 0xed, 0xf3,
  0x01, 0x23, 0xb6, 0xcd, 0x18, 0x03, 0x76, 0x33, 0xcc, 0x18, 0x03, 0x76,
  0x33, 0xcc, 0xf8, 0x03, 0xde, 0x33, 0xcc, 0x18, 0x00, 0x8c, 0x31, 0xcc,
  0x18, 0x03, 0x8c, 0x31, 0x8c, 0xf3, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
static char CmapA1_offi_mask[] = {
  0x00, 0x00, 0x1e, 0x00, 0x00, 0x00, 0x00, 0xfe, 0x01, 0x00, 0x00, 0x00,
  0xfe, 0x01, 0x00, 0x77, 0xff, 0xff, 0xff, 0x03, 0x77, 0xff, 0xff, 0xff,
  0x07, 0xff, 0xff, 0xff, 0xff, 0x07, 0xff, 0xff, 0xff, 0xfd, 0x07, 0xff,
  0x7f, 0xfe, 0xfd, 0x07, 0xff, 0x7f, 0xfe, 0xfd, 0x07, 0xff, 0x7f, 0xfe,
  0xff, 0x07, 0xde, 0x7b, 0xfe, 0xff, 0x07, 0xde, 0x7b, 0xde, 0xff, 0x03,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
static int CmapA1_offi_breaks[] = { 12, 18, 21, 27, 35 };
static ButtonLabel CmapA1_offi = {
  (unsigned char *)CmapA1_offi_label, (unsigned char *)CmapA1_offi_mask,
  CmapA1_offi_width, CmapA1_offi_height,
  0.5, 0.5, 0, 0,			/* placement */
  5, 5, 0, CmapA1_offi_breaks };
static ButtonLook CmapA1_look = {
  &CmapA1_offo, NULL, &CmapA1_offo, NULL,
  &CmapA1_offi, NULL, &CmapA1_offi, NULL };
static ButtonFeel CmapA1_feel = {
  "CmapA1", 2,
  { BTNFlash, BTNCoWhile },
  { 0x0004, 0x0004 },
  { 0x0000, 0x0004 },
  { 5, 48, 0, 0 } };
/* read button: CmapA2 */
#define CmapA2_offo_width 30
#define CmapA2_offo_height 14
static char CmapA2_offo_label[] = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x10,
  0x00, 0x00, 0x00, 0x10, 0x1a, 0x06, 0x07, 0x16, 0x06, 0x89, 0x08, 0x19,
  0x82, 0x10, 0x8c, 0x10, 0x82, 0x1f, 0x8b, 0x10, 0x82, 0x80, 0x88, 0x10,
  0x02, 0x91, 0x08, 0x19, 0x02, 0x0e, 0x17, 0x16, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
static char CmapA2_offo_mask[] = {
  0x00, 0x00, 0x00, 0x38, 0x00, 0x00, 0x00, 0x38, 0x00, 0x00, 0x00, 0x38,
  0x3f, 0x8f, 0x0f, 0x3f, 0xbf, 0xdf, 0x9f, 0x3f, 0xff, 0xff, 0xdf, 0x3f,
  0xcf, 0xff, 0xdf, 0x3f, 0xc7, 0xff, 0xdf, 0x39, 0xc7, 0xff, 0xdf, 0x3f,
  0xc7, 0xff, 0xff, 0x3f, 0x87, 0xff, 0xbf, 0x3f, 0x07, 0x9f, 0x3f, 0x3f,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
static int CmapA2_offo_breaks[] = { 6, 14, 22, 30 };
static ButtonLabel CmapA2_offo = {
  (unsigned char *)CmapA2_offo_label, (unsigned char *)CmapA2_offo_mask,
  CmapA2_offo_width, CmapA2_offo_height,
  0.5, 0.5, 0, 0,			/* placement */
  4, 4, 0, CmapA2_offo_breaks };
#define CmapA2_offi_width 30
#define CmapA2_offi_height 14
static char CmapA2_offi_label[] = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x18, 0x00, 0x00, 0x00, 0x18,
  0x00, 0x00, 0x00, 0x18, 0x9f, 0x8f, 0x87, 0x1f, 0xdb, 0xd8, 0xcc, 0x18,
  0xc3, 0x18, 0xcc, 0x18, 0xc3, 0x9f, 0xcf, 0x18, 0xc3, 0xc0, 0xcc, 0x18,
  0xc3, 0xd8, 0xcc, 0x18, 0x83, 0x8f, 0x9b, 0x1f, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
static char CmapA2_offi_mask[] = {
  0x00, 0x00, 0x00, 0x3c, 0x00, 0x00, 0x00, 0x3c, 0x00, 0x00, 0x00, 0x3c,
  0xff, 0xdf, 0xcf, 0x3f, 0xff, 0xff, 0xff, 0x3f, 0xff, 0xff, 0xff, 0x3f,
  0xff, 0xff, 0xff, 0x3d, 0xe7, 0xff, 0xff, 0x3d, 0xe7, 0xff, 0xff, 0x3d,
  0xe7, 0xff, 0xff, 0x3f, 0xe7, 0xff, 0xff, 0x3f, 0xc7, 0xdf, 0xff, 0x3f,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
static int CmapA2_offi_breaks[] = { 6, 14, 22, 30 };
static ButtonLabel CmapA2_offi = {
  (unsigned char *)CmapA2_offi_label, (unsigned char *)CmapA2_offi_mask,
  CmapA2_offi_width, CmapA2_offi_height,
  0.5, 0.5, 0, 0,			/* placement */
  4, 4, 0, CmapA2_offi_breaks };
static ButtonLook CmapA2_look = {
  &CmapA2_offo, NULL, &CmapA2_offo, NULL,
  &CmapA2_offi, NULL, &CmapA2_offi, NULL };
static ButtonFeel CmapA2_feel = {
  "CmapA2", 2,
  { BTNFlash, BTNCoWhile },
  { 0x0004, 0x0004 },
  { 0x0000, 0x0004 },
  { 5, 64, 0, 0 } };
/* Gray button: CmapA3 */
#define CmapA3_offo_width 34
#define CmapA3_offo_height 14
static char CmapA3_offo_label[] = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0xf0, 0x00, 0x00, 0x00, 0x00, 0x0c, 0x01,
  0x00, 0x00, 0x00, 0x04, 0x02, 0x00, 0x00, 0x00, 0x02, 0xd2, 0x38, 0x04,
  0x01, 0x02, 0x30, 0x44, 0x04, 0x01, 0xe2, 0x13, 0x60, 0x88, 0x00, 0x02,
  0x12, 0x58, 0x88, 0x00, 0x04, 0x12, 0x44, 0x50, 0x00, 0x0c, 0x13, 0x44,
  0x50, 0x00, 0xf0, 0x12, 0xb8, 0x20, 0x00, 0x00, 0x00, 0x00, 0x20, 0x00,
  0x00, 0x00, 0x00, 0x24, 0x00, 0x00, 0x00, 0x00, 0x18, 0x00 };
static char CmapA3_offo_mask[] = {
  0xf8, 0x01, 0x00, 0x00, 0x00, 0xfe, 0x03, 0x00, 0x00, 0x00, 0xfe, 0x07,
  0x00, 0x00, 0x00, 0x9f, 0xff, 0x7d, 0x8e, 0x03, 0x0f, 0xff, 0xff, 0x8e,
  0x03, 0xf7, 0xff, 0xff, 0xde, 0x03, 0xf7, 0x7f, 0xfe, 0xde, 0x03, 0xff,
  0x3f, 0xfe, 0xfc, 0x01, 0x9f, 0x3f, 0xfe, 0xfc, 0x01, 0xfe, 0x3f, 0xfe,
  0xf9, 0x00, 0xfe, 0x3f, 0xfe, 0xf9, 0x00, 0xf8, 0x3f, 0xfc, 0x7f, 0x00,
  0x00, 0x00, 0x00, 0x7e, 0x00, 0x00, 0x00, 0x00, 0x7e, 0x00 };
static int CmapA3_offo_breaks[] = { 11, 17, 25, 34 };
static ButtonLabel CmapA3_offo = {
  (unsigned char *)CmapA3_offo_label, (unsigned char *)CmapA3_offo_mask,
  CmapA3_offo_width, CmapA3_offo_height,
  0.5, 0.5, 0, 0,			/* placement */
  5, 4, 0, CmapA3_offo_breaks };
#define CmapA3_offi_width 32
#define CmapA3_offi_height 14
static char CmapA3_offi_label[] = {
  0x00, 0x00, 0x00, 0x00, 0xfc, 0x00, 0x00, 0x00, 0x86, 0x01, 0x00, 0x00,
  0x83, 0x01, 0x00, 0x00, 0x03, 0x7c, 0x1e, 0x63, 0x03, 0x6c, 0x33, 0x63,
  0xe3, 0x0d, 0x30, 0x66, 0x83, 0x0d, 0x3e, 0x36, 0x83, 0x0d, 0x33, 0x34,
  0xc6, 0x0d, 0x33, 0x3c, 0xbc, 0x0d, 0x6e, 0x18, 0x00, 0x00, 0x00, 0x18,
  0x00, 0x00, 0x00, 0x1b, 0x00, 0x00, 0x00, 0x0e };
static char CmapA3_offi_mask[] = {
  0xfe, 0x01, 0x00, 0x00, 0xff, 0x03, 0x00, 0x00, 0xff, 0x03, 0x00, 0x00,
  0xcf, 0xff, 0xbf, 0xf7, 0xc7, 0xff, 0xff, 0xf7, 0xf7, 0xff, 0xff, 0xff,
  0xf7, 0xff, 0xff, 0xff, 0xf7, 0x9f, 0x7f, 0xff, 0xef, 0x9f, 0x7f, 0x7f,
  0xff, 0x9f, 0xff, 0x7e, 0xff, 0x9f, 0xff, 0x7e, 0xfe, 0x1f, 0xff, 0x3f,
  0x00, 0x00, 0x80, 0x3f, 0x00, 0x00, 0x80, 0x3f };
static int CmapA3_offi_breaks[] = { 10, 16, 24, 32 };
static ButtonLabel CmapA3_offi = {
  (unsigned char *)CmapA3_offi_label, (unsigned char *)CmapA3_offi_mask,
  CmapA3_offi_width, CmapA3_offi_height,
  0.5, 0.5, 0, 0,			/* placement */
  4, 4, 0, CmapA3_offi_breaks };
static ButtonLook CmapA3_look = {
  &CmapA3_offo, NULL, &CmapA3_offo, NULL,
  &CmapA3_offi, NULL, &CmapA3_offi, NULL };
static ButtonFeel CmapA3_feel = {
  "CmapA3", 2,
  { BTNOneShot, BTNCoWhile },
  { 0x0004, 0x0004 },
  { 0x0000, 0x0004 },
  { 5, 256, 0, 0 } };
/* BB button: CmapA4 */
#define CmapA4_offo_width 18
#define CmapA4_offo_height 12
static char CmapA4_offo_label[] = {
  0x00, 0x00, 0x00, 0x7e, 0xfc, 0x00, 0x82, 0x04, 0x01, 0x82, 0x04, 0x01,
  0x82, 0x04, 0x01, 0x7e, 0xfc, 0x00, 0x82, 0x04, 0x01, 0x82, 0x04, 0x01,
  0x82, 0x04, 0x01, 0x82, 0x04, 0x01, 0x7e, 0xfc, 0x00, 0x00, 0x00, 0x00 };
static char CmapA4_offo_mask[] = {
  0xff, 0xfe, 0x01, 0xff, 0xff, 0x03, 0xff, 0xff, 0x03, 0xc7, 0x8f, 0x03,
  0xff, 0xff, 0x03, 0xff, 0xff, 0x03, 0xff, 0xff, 0x03, 0xc7, 0x8f, 0x03,
  0xc7, 0x8f, 0x03, 0xff, 0xff, 0x03, 0xff, 0xff, 0x03, 0xff, 0xfe, 0x01 };
static int CmapA4_offo_breaks[] = { 9, 18 };
static ButtonLabel CmapA4_offo = {
  (unsigned char *)CmapA4_offo_label, (unsigned char *)CmapA4_offo_mask,
  CmapA4_offo_width, CmapA4_offo_height,
  0.5, 0.5, 0, 0,			/* placement */
  3, 2, 0, CmapA4_offo_breaks };
#define CmapA4_offi_width 16
#define CmapA4_offi_height 12
static char CmapA4_offi_label[] = {
  0x00, 0x00, 0x1f, 0x1f, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x3f, 0x3f,
  0x63, 0x63, 0x63, 0x63, 0x63, 0x63, 0x63, 0x63, 0x3f, 0x3f, 0x00, 0x00 };
static char CmapA4_offi_mask[] = {
  0xbf, 0x3f, 0xff, 0x7f, 0xff, 0x7f, 0xff, 0x7f, 0xff, 0x7f, 0xff, 0xff,
  0xff, 0xff, 0xf7, 0xf7, 0xf7, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f };
static int CmapA4_offi_breaks[] = { 8, 16 };
static ButtonLabel CmapA4_offi = {
  (unsigned char *)CmapA4_offi_label, (unsigned char *)CmapA4_offi_mask,
  CmapA4_offi_width, CmapA4_offi_height,
  0.5, 0.5, 0, 0,			/* placement */
  2, 2, 0, CmapA4_offi_breaks };
static ButtonLook CmapA4_look = {
  &CmapA4_offo, NULL, &CmapA4_offo, NULL,
  &CmapA4_offi, NULL, &CmapA4_offi, NULL };
static ButtonFeel CmapA4_feel = {
  "CmapA4", 2,
  { BTNOneShot, BTNCoWhile },
  { 0x0004, 0x0004 },
  { 0x0000, 0x0004 },
  { 5, 512, 0, 0 } };
/* HE button: CmapA5 */
#define CmapA5_offo_width 19
#define CmapA5_offo_height 12
static char CmapA5_offo_label[] = {
  0x00, 0x00, 0x00, 0x02, 0xf9, 0x03, 0x02, 0x09, 0x00, 0x02, 0x09, 0x00,
  0x02, 0x09, 0x00, 0xfe, 0xf9, 0x01, 0x02, 0x09, 0x00, 0x02, 0x09, 0x00,
  0x02, 0x09, 0x00, 0x02, 0x09, 0x00, 0x02, 0xf9, 0x03, 0x00, 0x00, 0x00 };
static char CmapA5_offo_mask[] = {
  0x87, 0xff, 0x07, 0x87, 0xff, 0x07, 0x87, 0xff, 0x07, 0x87, 0x1f, 0x00,
  0xff, 0xff, 0x03, 0xff, 0xff, 0x03, 0xff, 0xff, 0x03, 0x87, 0x1f, 0x00,
  0x87, 0x1f, 0x00, 0x87, 0xff, 0x07, 0x87, 0xff, 0x07, 0x87, 0xff, 0x07 };
static int CmapA5_offo_breaks[] = { 10, 19 };
static ButtonLabel CmapA5_offo = {
  (unsigned char *)CmapA5_offo_label, (unsigned char *)CmapA5_offo_mask,
  CmapA5_offo_width, CmapA5_offo_height,
  0.5, 0.5, 0, 0,			/* placement */
  3, 2, 0, CmapA5_offo_breaks };
#define CmapA5_offi_width 17
#define CmapA5_offi_height 12
static char CmapA5_offi_label[] = {
  0x00, 0x00, 0x00, 0xc3, 0xfe, 0x00, 0xc3, 0x06, 0x00, 0xc3, 0x06, 0x00,
  0xc3, 0x06, 0x00, 0xff, 0x7e, 0x00, 0xc3, 0x06, 0x00, 0xc3, 0x06, 0x00,
  0xc3, 0x06, 0x00, 0xc3, 0x06, 0x00, 0xc3, 0xfe, 0x00, 0x00, 0x00, 0x00 };
static char CmapA5_offi_mask[] = {
  0xe7, 0xff, 0x01, 0xe7, 0xff, 0x01, 0xe7, 0xff, 0x01, 0xe7, 0x0f, 0x00,
  0xff, 0xff, 0x00, 0xff, 0xff, 0x00, 0xff, 0xff, 0x00, 0xe7, 0x0f, 0x00,
  0xe7, 0x0f, 0x00, 0xe7, 0xff, 0x01, 0xe7, 0xff, 0x01, 0xe7, 0xff, 0x01 };
static int CmapA5_offi_breaks[] = { 9, 17 };
static ButtonLabel CmapA5_offi = {
  (unsigned char *)CmapA5_offi_label, (unsigned char *)CmapA5_offi_mask,
  CmapA5_offi_width, CmapA5_offi_height,
  0.5, 0.5, 0, 0,			/* placement */
  3, 2, 0, CmapA5_offi_breaks };
static ButtonLook CmapA5_look = {
  &CmapA5_offo, NULL, &CmapA5_offo, NULL,
  &CmapA5_offi, NULL, &CmapA5_offi, NULL };
static ButtonFeel CmapA5_feel = {
  "CmapA5", 2,
  { BTNOneShot, BTNCoWhile },
  { 0x0004, 0x0004 },
  { 0x0000, 0x0004 },
  { 5, 768, 0, 0 } };
/* I8 button: CmapA6 */
#define CmapA6_offo_width 12
#define CmapA6_offo_height 12
static char CmapA6_offo_label[] = {
  0x00, 0x00, 0xc2, 0x01, 0x22, 0x02, 0x22, 0x02, 0x22, 0x02, 0xc2, 0x01,
  0x22, 0x02, 0x12, 0x04, 0x12, 0x04, 0x22, 0x02, 0xc2, 0x01, 0x00, 0x00 };
static char CmapA6_offo_mask[] = {
  0xe7, 0x03, 0xf7, 0x07, 0xf7, 0x07, 0x77, 0x07, 0xf7, 0x07, 0xf7, 0x07,
  0xff, 0x0f, 0x7f, 0x0f, 0x7f, 0x0f, 0xff, 0x0f, 0xf7, 0x07, 0xe7, 0x03 };
static int CmapA6_offo_breaks[] = { 3, 12 };
static ButtonLabel CmapA6_offo = {
  (unsigned char *)CmapA6_offo_label, (unsigned char *)CmapA6_offo_mask,
  CmapA6_offo_width, CmapA6_offo_height,
  0.5, 0.5, 0, 0,			/* placement */
  2, 2, 0, CmapA6_offo_breaks };
#define CmapA6_offi_width 12
#define CmapA6_offi_height 12
static char CmapA6_offi_label[] = {
  0x00, 0x00, 0xe3, 0x03, 0x33, 0x06, 0x33, 0x06, 0x33, 0x06, 0xe3, 0x03,
  0x33, 0x06, 0x33, 0x06, 0x33, 0x06, 0x33, 0x06, 0xe3, 0x03, 0x00, 0x00 };
static char CmapA6_offi_mask[] = {
  0xf7, 0x07, 0xff, 0x0f, 0xff, 0x0f, 0x7f, 0x0f, 0xff, 0x0f, 0xff, 0x0f,
  0xff, 0x0f, 0x7f, 0x0f, 0x7f, 0x0f, 0xff, 0x0f, 0xff, 0x0f, 0xf7, 0x07 };
static int CmapA6_offi_breaks[] = { 3, 12 };
static ButtonLabel CmapA6_offi = {
  (unsigned char *)CmapA6_offi_label, (unsigned char *)CmapA6_offi_mask,
  CmapA6_offi_width, CmapA6_offi_height,
  0.5, 0.5, 0, 0,			/* placement */
  2, 2, 0, CmapA6_offi_breaks };
static ButtonLook CmapA6_look = {
  &CmapA6_offo, NULL, &CmapA6_offo, NULL,
  &CmapA6_offi, NULL, &CmapA6_offi, NULL };
static ButtonFeel CmapA6_feel = {
  "CmapA6", 2,
  { BTNOneShot, BTNCoWhile },
  { 0x0004, 0x0004 },
  { 0x0000, 0x0004 },
  { 5, 1024, 0, 0 } };
/* A button: CmapA7 */
#define CmapA7_offo_width 10
#define CmapA7_offo_height 12
static char CmapA7_offo_label[] = {
  0x00, 0x00, 0x30, 0x00, 0x30, 0x00, 0x48, 0x00, 0x48, 0x00, 0x48, 0x00,
  0x84, 0x00, 0xfc, 0x00, 0x84, 0x00, 0x02, 0x01, 0x02, 0x01, 0x00, 0x00 };
static char CmapA7_offo_mask[] = {
  0x78, 0x00, 0x78, 0x00, 0xfc, 0x00, 0xfc, 0x00, 0xfc, 0x00, 0xfe, 0x01,
  0xfe, 0x01, 0xfe, 0x01, 0xff, 0x03, 0xcf, 0x03, 0x87, 0x03, 0x87, 0x03 };
static int CmapA7_offo_breaks[] = { 10 };
static ButtonLabel CmapA7_offo = {
  (unsigned char *)CmapA7_offo_label, (unsigned char *)CmapA7_offo_mask,
  CmapA7_offo_width, CmapA7_offo_height,
  0.5, 0.5, 0, 0,			/* placement */
  2, 1, 0, CmapA7_offo_breaks };
#define CmapA7_offi_width 9
#define CmapA7_offi_height 12
static char CmapA7_offi_label[] = {
  0x00, 0x00, 0x18, 0x00, 0x18, 0x00, 0x3c, 0x00, 0x3c, 0x00, 0x24, 0x00,
  0x66, 0x00, 0x7e, 0x00, 0x66, 0x00, 0xc3, 0x00, 0xc3, 0x00, 0x00, 0x00 };
static char CmapA7_offi_mask[] = {
  0x3c, 0x00, 0x3c, 0x00, 0x7e, 0x00, 0x7e, 0x00, 0x7e, 0x00, 0xff, 0x00,
  0xff, 0x00, 0xff, 0x00, 0xff, 0x01, 0xff, 0x01, 0xe7, 0x01, 0xe7, 0x01 };
static int CmapA7_offi_breaks[] = { 9 };
static ButtonLabel CmapA7_offi = {
  (unsigned char *)CmapA7_offi_label, (unsigned char *)CmapA7_offi_mask,
  CmapA7_offi_width, CmapA7_offi_height,
  0.5, 0.5, 0, 0,			/* placement */
  2, 1, 0, CmapA7_offi_breaks };
static ButtonLook CmapA7_look = {
  &CmapA7_offo, NULL, &CmapA7_offo, NULL,
  &CmapA7_offi, NULL, &CmapA7_offi, NULL };
static ButtonFeel CmapA7_feel = {
  "CmapA7", 2,
  { BTNOneShot, BTNCoWhile },
  { 0x0004, 0x0004 },
  { 0x0000, 0x0004 },
  { 5, 1280, 0, 0 } };
/* B button: CmapA8 */
#define CmapA8_offo_width 9
#define CmapA8_offo_height 12
static char CmapA8_offo_label[] = {
  0x00, 0x00, 0x7e, 0x00, 0x82, 0x00, 0x82, 0x00, 0x82, 0x00, 0x7e, 0x00,
  0x82, 0x00, 0x82, 0x00, 0x82, 0x00, 0x82, 0x00, 0x7e, 0x00, 0x00, 0x00 };
static char CmapA8_offo_mask[] = {
  0xff, 0x00, 0xff, 0x01, 0xff, 0x01, 0xc7, 0x01, 0xff, 0x01, 0xff, 0x01,
  0xff, 0x01, 0xc7, 0x01, 0xc7, 0x01, 0xff, 0x01, 0xff, 0x01, 0xff, 0x00 };
static int CmapA8_offo_breaks[] = { 9 };
static ButtonLabel CmapA8_offo = {
  (unsigned char *)CmapA8_offo_label, (unsigned char *)CmapA8_offo_mask,
  CmapA8_offo_width, CmapA8_offo_height,
  0.5, 0.5, 0, 0,			/* placement */
  2, 1, 0, CmapA8_offo_breaks };
#define CmapA8_offi_width 8
#define CmapA8_offi_height 12
static char CmapA8_offi_label[] = {
  0x00, 0x1f, 0x33, 0x33, 0x33, 0x3f, 0x63, 0x63, 0x63, 0x63, 0x3f, 0x00 };
static char CmapA8_offi_mask[] = {
  0x3f, 0x7f, 0x7f, 0x7f, 0x7f, 0xff, 0xff, 0xf7, 0xf7, 0xff, 0xff, 0x7f };
static int CmapA8_offi_breaks[] = { 8 };
static ButtonLabel CmapA8_offi = {
  (unsigned char *)CmapA8_offi_label, (unsigned char *)CmapA8_offi_mask,
  CmapA8_offi_width, CmapA8_offi_height,
  0.5, 0.5, 0, 0,			/* placement */
  1, 1, 0, CmapA8_offi_breaks };
static ButtonLook CmapA8_look = {
  &CmapA8_offo, NULL, &CmapA8_offo, NULL,
  &CmapA8_offi, NULL, &CmapA8_offi, NULL };
static ButtonFeel CmapA8_feel = {
  "CmapA8", 2,
  { BTNOneShot, BTNCoWhile },
  { 0x0004, 0x0004 },
  { 0x0000, 0x0004 },
  { 5, 1536, 0, 0 } };
static ButtonSpec CmapA[] = {
  { &CmapA1_look, &CmapA1_feel },
  { &CmapA2_look, &CmapA2_feel },
  { &CmapA3_look, &CmapA3_feel },
  { &CmapA4_look, &CmapA4_feel },
  { &CmapA5_look, &CmapA5_feel },
  { &CmapA6_look, &CmapA6_feel },
  { &CmapA7_look, &CmapA7_feel },
  { &CmapA8_look, &CmapA8_feel } };
static BoxGeometry CmapA_geo = 
  { 0, 8, 8, 1, 9.333000, 1.000000, 0.000000, 0.000000, 0, 1 };

void MakeCmapPanel ( box, parent, gc, visual, background )
     BoxParent *parent;
     ButtonBox box[1];
     GC gc;
     Visual *visual;
     unsigned long background;
{
  box[0] = MakeButtonBox(&parent[1], gc, visual, background,
			 &CmapA_geo, CmapA, 0);
}
